@@ -1,12 +1,10 @@
 #!/usr/bin/env perl
-use strict;
-use warnings;
+use strict; use warnings;
 use rlib '../lib';
 use Enbugger 'trepan';
 # GCD. We assume positive numbers
-sub gcd($$);
-sub gcd($$) 
-{ 
+sub gcd($$)
+{
     Enbugger->stop;
     my ($a, $b) = @_;
     # Make: a <= b
@@ -17,7 +15,7 @@ sub gcd($$)
     return gcd($b-$a, $a);
 }
 
-die sprintf "Need two integer arguments, got %d", scalar(@ARGV) unless 
+die sprintf "Need two integer arguments, got %d", scalar(@ARGV) unless
     @ARGV == 2;
 my ($a, $b) = @ARGV[0,1];
 printf "The GCD of %d and %d is %d\n", $a, $b, gcd($a, $b);
